@@ -18,6 +18,7 @@ from io import StringIO
 import requests
 import httpx
 from tenacity import retry
+from tenacity.wait import wait_exponential
 from tenacity.stop import stop_after_attempt
 from urllib.error import HTTPError  # for Python 3
 
@@ -185,9 +186,11 @@ def get_geo_accession_soft(
         targ, accession, view
     )
 
-    @retry(stop=stop_after_attempt(10))
+    @retry(
+        wait=wait_exponential(multiplier=1, min=10, max=60), stop=stop_after_attempt(30)
+    )
     def _perform_get(url: str) -> str:
-        resp = httpx.get(url)
+        resp = httpx.get(url, timeout=120)
         resp.raise_for_status()
         return resp.text
 
